.. image:: http://dadard.fr:8010/dadard/YtApi/raw/branch/master/static/static/favicon.png
        :target: http://dadard.fr:8010/dadard/YtApi/raw/branch/master/static/static/favicon.png


.. image:: http://dadard.fr:8020/api/badges/dadard/YtApi/status.svg
        :target: http://dadard.fr:8020/api/badges/dadard/YtApi/status.svg

.. image:: https://badge.fury.io/py/YtApi.svg
        :target: https://badge.fury.io/py/YtApi.svg



Purpose
-------

This is a Web API to manage and download Youtube videos as mp3 files.

By using your API key, you can manager your own list of videos, and when its complete download all its content with one click

You can also add to your list all the content of a Youtube playlist, which makes the job easier.

This extraction part will be used later to train a Machine Learning model, to recognize music type from a file.

Source
------

Bo-Peep_ image

.. _Bo-Peep: https://www.pinterest.fr/pin/116178865374546282/
